@@ -25,9 +25,8 @@
  * setting it there prevents us from testing some of the downstream overflow
  * logic.
  */
-
 int FANSI_int_max = INT_MAX;
-int FANSI_int_min = INT_MIN;  // currently no external interface for this
+int FANSI_int_min = INT_MIN;  // no way to change this externally
 
 SEXP FANSI_set_int_max(SEXP x) {
   if(TYPEOF(x) != INTSXP || XLENGTH(x) != 1)
@@ -116,7 +115,7 @@ struct FANSI_csi_pos FANSI_find_esc(const char * x, int what) {
     int found_this = 0;
 
     // If not normal ASCII or UTF8, examine whether we need to found
-    if(!((x_val > 31 && x_val < 127) || x_val < 0)) {
+    if(!((x_val > 31 && x_val < 127) || x_val < 0 || x_val > 127)) {
       if(!found) {
         // Keep resetting strip start point until we find something we want to
         // mark
@@ -278,20 +277,29 @@ SEXP FANSI_digits_in_int_ext(SEXP y) {
   return(res);
 }
 /*
- * Compresses the what vector into a single integer
+ * Compresses the what vector into a single integer by encoding each value of
+ * what as a bit.
  */
 
 int FANSI_what_as_int(SEXP what) {
   int what_int = 0;
   int flip_bits = 0;
   for(R_xlen_t i = 0; i < XLENGTH(what); ++i) {
+    // -2 because what is 1 indexed (from R), and position 1 means "all", so we
+    // need to shift by 1 for the 0 index, and then by one more for the position
+    // occupied by "all" that really means flip bits
     int what_val = INTEGER(what)[i] - 2;
+    if(what_val > 4)
+      error("Internal Error: max what value allowed is 4.");
     if(what_val < 0) flip_bits = 1;
     else what_int |= 1 << what_val;
   }
   if(flip_bits) what_int ^= FANSI_STRIP_ALL;
   return what_int;
 }
+SEXP FANSI_what_as_int_ext(SEXP what) {
+  return ScalarInteger(FANSI_what_as_int(what));
+}
 /*
  * Partial match a single string byte by byte
  *
